@@ -1,7 +1,7 @@
 # # TESTING #
 # ############################################################
 # ######################Create Dataset########################
-#df <- read.csv(file = "climas2018.csv", header = TRUE, sep = ",")
+# df <- read.csv(file = "climas2018.csv", header = TRUE, sep = ",")
 # df <- as.data.frame(list("FEATURE_1" = c("VALUE_1", "VALUE_2"), "FEATURE_2" = c("VALUE_3", "VALUE_4")))
 # action <- "API_createDataset"
 # parameters <- list(
@@ -10,8 +10,8 @@
 #   name = "df_from_R_object",
 #   descriptipon = "testing R library for OpenBlender",
 #   visibility = "public",
-#   tags = list("weather", "climate"),
-#   insert_observations = "on",
+#   tags = list("tag1", "tag2"),
+#   insert_observations = "off",
 #   dataframe = df
 # )
 # new_df <- openblender::call(action, parameters)
@@ -19,7 +19,7 @@
 # ############################################################
 # #####################Insert observations####################
 # df <- read.csv(file = "climas2018.csv", header = TRUE, sep = ",")
-# nrow(df)
+# df
 # action <- "API_insertObservations"
 # parameters <- list(
 #   #oblender = 1,
@@ -30,16 +30,20 @@
 #   observations = df
 # )
 # response <- openblender::call(action, parameters)
+# response
 # ############################################################
 # #####################Obtain observations####################
-#with daniel.pinacho
-action <- "API_getObservationsFromDataset"
-parameters <- list(
-  test_call = "off",
-  token = "1AKnDhP09wa2yGRia5z1SGTxAUQAiV",
-  id_user = "5d07bed33e59b27a93e43be8",
-  id_dataset = "5d5ac4a89516296e58c5b832"
-)
-
-dfr <- openblender::call(action, parameters)$sample
-head(dfr)
+# with daniel.pinacho
+# action <- "API_getObservationsFromDataset"
+# parameters <- list(
+#   oblender = 1,
+#   token = "67dTvR8KVRM044s9ldE94IgFc5HF3q",
+#   id_user = "5d48b439275b3f05db0feee2",
+#   id_dataset = "5d533b864b81b70af19bdc4c"
+# )
+#
+# response <- openblender::call(action, parameters)
+# dfr <- response$sample
+# head(dfr)
+# nrow(dfr)
+# dfr
